# (c) Pentalogic Technology - 30th April 2019

# Aim - use to get a list of all Lists in a SharePoint site that use the Highlighter custom column
# http://www.pentalogic.net/sharepoint-products/highlighter
# Will iterate through all webs in the site collection given

# Compatability -  SharePoint 2013+

# This does not form part of the product as is provided on an as is basis.
# *** Providing technical support for this is outside of the scope of the support we offer for the product but we will do our best to help***

# Usage
# ====
# Copy this script into a drectory on one of your SharePoint servers
# Start the SharePoint Management Shell (as Administrator if necessary)
# CD to the directory you created above
# Call with the URL of your site, e.g.
#.\FindWhereHighligherUsed.ps1 https://yoursiteurl/
# You can also write the output to a file as well as the console with TEE e.g.
#.\FindWhereHighligherUsed.ps1 https://yoursiteurl/ | TEE highlighter_fields.txt

# TIP - if the columns are too narrow to fit the URL's in then widen your powershell window 
#       (may have to right click on the menu bar > properties > layout and increase screen buffer size width )

Param(
    [Parameter(Mandatory)]    
    [String]$webURL    
)

if($null -eq (Get-PSSnapin | Where {$_.Name -eq "Microsoft.SharePoint.PowerShell"})) {
    Add-PSSnapin Microsoft.SharePoint.PowerShell;
}

Start-SPAssignment -Global  

$spWeb = Get-SPWeb $webURL
$spSite = $spWeb.site

Write-Output "Found root site at $spSite.Url"
Write-Output " * Searching for Pentalogic Highlighter fields in use"

$highlighterFields = New-Object System.Collections.ArrayList
foreach ($spWeb in $spSite.AllWebs) {
    foreach ($list in $spWeb.Lists) {
        foreach ($field in $list.Fields) { 
            if ($field.TypeDisplayName -eq "Pentalogic Highlighter") {                
                $f = [pscustomobject]@{
                    Site     = $spWeb.URL
                    URL      = $list.URL
                    ListName = $list.Title
                    Field    = $field.Title
                } 
                $highlighterFields.Add($f) | Out-Null
            } 
        }
    }
}
$highlighterFields | Format-Table URL, ListName, Field -AutoSize -GroupBy Site

Stop-SPAssignment -global

Write-Host "Finished" -f Green